package io.xjar.jar;

import io.xjar.XDecryptor;
import io.xjar.XJdkDecryptor;
import io.xjar.XKit;
import org.apache.commons.compress.archivers.jar.JarArchiveEntry;
import io.xjar.XEntryFilter;
import java.io.OutputStream;
import java.io.InputStream;
import io.xjar.XEncryptor;
import io.xjar.XJdkEncryptor;
import java.io.File;
import io.xjar.key.XKey;
import io.xjar.XConstants;
import io.xjar.XFilters;

public class XJar extends XFilters implements XConstants
{
    public static void encrypt(final String src, final String dest, final XKey xKey) throws Exception {
        encrypt(new File(src), new File(dest), xKey);
    }
    
    public static void encrypt(final File src, final File dest, final XKey xKey) throws Exception {
        final XJarEncryptor xJarEncryptor = new XJarEncryptor((XEncryptor)new XJdkEncryptor());
        xJarEncryptor.encrypt(xKey, src, dest);
    }
    
    public static void encrypt(final InputStream in, final OutputStream out, final XKey xKey) throws Exception {
        final XJarEncryptor xJarEncryptor = new XJarEncryptor((XEncryptor)new XJdkEncryptor());
        xJarEncryptor.encrypt(xKey, in, out);
    }
    
    public static void encrypt(final String src, final String dest, final XKey xKey, final XEntryFilter<JarArchiveEntry> filter) throws Exception {
        encrypt(new File(src), new File(dest), xKey, filter);
    }
    
    public static void encrypt(final File src, final File dest, final XKey xKey, final XEntryFilter<JarArchiveEntry> filter) throws Exception {
        final XJarEncryptor xJarEncryptor = new XJarEncryptor((XEncryptor)new XJdkEncryptor(), filter);
        xJarEncryptor.encrypt(xKey, src, dest);
    }
    
    public static void encrypt(final InputStream in, final OutputStream out, final XKey xKey, final XEntryFilter<JarArchiveEntry> filter) throws Exception {
        final XJarEncryptor xJarEncryptor = new XJarEncryptor((XEncryptor)new XJdkEncryptor(), filter);
        xJarEncryptor.encrypt(xKey, in, out);
    }
    
    public static void encrypt(final String src, final String dest, final String password) throws Exception {
        encrypt(src, dest, XKit.key(password));
    }
    
    public static void encrypt(final File src, final File dest, final String password) throws Exception {
        encrypt(src, dest, XKit.key(password));
    }
    
    public static void encrypt(final InputStream in, final OutputStream out, final String password) throws Exception {
        encrypt(in, out, XKit.key(password));
    }
    
    public static void encrypt(final String src, final String dest, final String password, final XEntryFilter<JarArchiveEntry> filter) throws Exception {
        encrypt(src, dest, XKit.key(password), filter);
    }
    
    public static void encrypt(final File src, final File dest, final String password, final XEntryFilter<JarArchiveEntry> filter) throws Exception {
        encrypt(src, dest, XKit.key(password), filter);
    }
    
    public static void encrypt(final InputStream in, final OutputStream out, final String password, final XEntryFilter<JarArchiveEntry> filter) throws Exception {
        encrypt(in, out, XKit.key(password), filter);
    }
    
    public static void decrypt(final String src, final String dest, final XKey xKey) throws Exception {
        decrypt(new File(src), new File(dest), xKey);
    }
    
    public static void decrypt(final File src, final File dest, final XKey xKey) throws Exception {
        final XJarDecryptor xJarDecryptor = new XJarDecryptor((XDecryptor)new XJdkDecryptor());
        xJarDecryptor.decrypt(xKey, src, dest);
    }
    
    public static void decrypt(final InputStream in, final OutputStream out, final XKey xKey) throws Exception {
        final XJarDecryptor xJarDecryptor = new XJarDecryptor((XDecryptor)new XJdkDecryptor());
        xJarDecryptor.decrypt(xKey, in, out);
    }
    
    public static void decrypt(final String src, final String dest, final XKey xKey, final XEntryFilter<JarArchiveEntry> filter) throws Exception {
        decrypt(new File(src), new File(dest), xKey, filter);
    }
    
    public static void decrypt(final File src, final File dest, final XKey xKey, final XEntryFilter<JarArchiveEntry> filter) throws Exception {
        final XJarDecryptor xJarDecryptor = new XJarDecryptor((XDecryptor)new XJdkDecryptor(), filter);
        xJarDecryptor.decrypt(xKey, src, dest);
    }
    
    public static void decrypt(final InputStream in, final OutputStream out, final XKey xKey, final XEntryFilter<JarArchiveEntry> filter) throws Exception {
        final XJarDecryptor xJarDecryptor = new XJarDecryptor((XDecryptor)new XJdkDecryptor(), filter);
        xJarDecryptor.decrypt(xKey, in, out);
    }
    
    public static void decrypt(final String src, final String dest, final String password) throws Exception {
        decrypt(src, dest, XKit.key(password));
    }
    
    public static void decrypt(final File src, final File dest, final String password) throws Exception {
        decrypt(src, dest, XKit.key(password));
    }
    
    public static void decrypt(final InputStream in, final OutputStream out, final String password) throws Exception {
        decrypt(in, out, XKit.key(password));
    }
    
    public static void decrypt(final String src, final String dest, final String password, final XEntryFilter<JarArchiveEntry> filter) throws Exception {
        decrypt(src, dest, XKit.key(password), filter);
    }
    
    public static void decrypt(final File src, final File dest, final String password, final XEntryFilter<JarArchiveEntry> filter) throws Exception {
        decrypt(src, dest, XKit.key(password), filter);
    }
    
    public static void decrypt(final InputStream in, final OutputStream out, final String password, final XEntryFilter<JarArchiveEntry> filter) throws Exception {
        decrypt(in, out, XKit.key(password), filter);
    }
}
